#
# spec file for package jefferson
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jefferson
Version:        0.4.1+git.20220705
Release:        1.11
Summary:        JFFS2 filesystem extraction tool
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/sviehb/jefferson
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  python-rpm-macros
BuildRequires:  python3-cstruct >= 2.1
BuildRequires:  python3-pylzma
BuildRequires:  python3-setuptools
Requires:       python3-cstruct >= 2.1
Requires:       python3-pylzma
BuildArch:      noarch

%description
A JFFS2 filesystem extraction tool written in python.

Features:
 - Big/Little Endian support
 - JFFS2_COMPR_ZLIB, JFFS2_COMPR_RTIME, and
   JFFS2_COMPR_LZMA compression support
 - CRC checks - for now only enforced on hdr_crc
 - Extraction of symlinks, directories, files, and device nodes
 - Detection/handling of duplicate inode numbers. Occurs if multiple
   JFFS2 filesystems are found in one file and causes jefferson
   to treat segments as separate filesystems

%prep
%setup -q
chmod -x README.md

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitelib}
export PYTHONPATH=%{buildroot}%{python3_sitelib}
help2man %{buildroot}/%{_bindir}/jefferson --no-discard-stderr --version-string="%{version}" --no-info > jefferson.1
install -Dpm 0644 %{name}.1 %{buildroot}/%{_mandir}/man1/%{name}.1

%files
%license LICENSE
%doc README.md
%{_bindir}/jefferson
%{_mandir}/man1/jefferson.1%{?ext_man}
%{python3_sitelib}/jefferson*

%changelog
* Fri Oct 14 2022 mardnh@gmx.de
- Update to version 0.4.1+git.20220705:
  * Fix is_safe_path call to use absolute path rather than
    relative path to execution directory.
  * Fix extraction of files with size greater than one erase block.
  * Remove unnecessary log call.
  * Keep xattr, xref, and summary nodetypes in order to propely
    identify unknown node types.
  * Remove handling of xref nodes, xattr nodes, summary nodes.
  * Use inode indexed dicts for inodes, dirent, and xref entries.
  * Simplify filesystem structure.
  * Fix duplicate inodes handling.
  * Fix support for python 3.10 by pinning python-lzo to 1.14.
  * Better handling of decompression error + simpler endianness
    logging.
  * Memory-mapped file support
  * Add support for LZO compression.
  * Revert the symlink path traversal check as it does not present
    a direct risk to normal end users. Those checks can be
    implemented by other tools where required.
  * Fix path traversal security vulnerability by canonicalizing
    path names of every inodes and discarding inodes with a path
    pointing outside of the extraction directory.
  * Autodetect endianness rather than scan the filesystem twice,
    one for each possible endianness. We make the assumption that
    a JFFS2 has always a fixed endianness and that nodes won't
    switch between endianness in the middle of a filesystem.
  * Add support for JFFS2 old magic signature (0x1984).
  * pin cstruct version to 2.1 so we don't end up with breaking
    API changes in the future. Moving to more recent versions
    should be done manually once it's been tested that jefferson
    still works with the newly released version of cstruct.
  * Fix set_endianness to support cstruct version 2.1.
  * Converted python2 encode("hex") to python3 hex()
  * Switched to lzma in python stdlib
  * Convert to python3.
- Drop patches:
  * 18.patch
  * jefferson-use-pylzma.patch
* Thu Aug 13 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.3+git.20160616
